# @bhplugin/vue3-datatable

## Example

[Demos](Coming Soon)

## Install

#### NPM

```bash
npm install @bhplugin/vue3-datatable --save
```

#### Yarn

```bash
yarn add @bhplugin/vue3-datatable
```

#### Bower

```bash
bower install @bhplugin/vue3-datatable --save
```

## Development Setup

```bash
# install dependencies
npm install

# build dist files
npm run build
```

## Usage

```html
<template>
  <vue3-datatable :rows="rows" :columns="cols" :totalRows="rows?.length">
  </vue3-datatable>
</template>

<script setup lang="ts">
  import { ref } from "vue";
  import Vue3Datatable from "@bhplugin/vue3-datatable";
  import "@bhplugin/vue3-datatable/dist/style.css";

  const cols =
    ref([
      { field: "id", title: "ID", width: "90px", filter: false },
      { field: "name", title: "Name" },
      { field: "username", title: "Username" },
      { field: "email", title: "Email" },
      { field: "phone", title: "Phone" },
      { field: "date", title: "Date", type: "date" },
      { field: "active", title: "Active", type: "bool" },
      { field: "age", title: "Age", type: "number" },
      {
        field: "address.city",
        title: "Address",
        search: true,
        cellRenderer: (item: any) => {
          return (
            item &&
            item.address?.street +
              ", " +
              item.address?.suite +
              "<br/><strong>" +
              item.address?.city +
              "</strong>" +
              "<br/><strong>" +
              "lat: " +
              item.address?.geo?.lat +
              "&nbsp;&nbsp; lng: " +
              item.address?.geo?.lng +
              "</strong>"
          );
        },
      },
      { field: "company.name", title: "Company" },
    ]) || [];

  const rows = ref([
    {
      id: 1,
      name: "Leanne Graham",
      username: "Bret",
      email: "Sincere@april.biz",
      address: {
        street: "Kulas Light",
        suite: "Apt. 556",
        city: "Gwenborough",
        zipcode: "92998-3874",
        geo: {
          lat: "-37.3159",
          lng: "81.1496",
        },
      },
      phone: "1-770-736-8031 x56442",
      website: "hildegard.org",
      company: {
        name: "Romaguera-Crona",
        catchPhrase: "Multi-layered client-server neural-net",
        bs: "harness real-time e-markets",
      },
      date: "Tue Sep 27 2022 22:19:57",
      active: true,
      age: 10,
    },
    {
      id: 2,
      name: "Ervin Howell",
      username: "Antonette",
      email: "Shanna@melissa.tv",
      address: {
        street: "Victor Plains",
        suite: "Suite 879",
        city: "Wisokyburgh",
        zipcode: "90566-7771",
        geo: {
          lat: "-43.9509",
          lng: "-34.4618",
        },
      },
      phone: "010-692-6593 x09125",
      website: "anastasia.net",
      company: {
        name: "Deckow-Crist",
        catchPhrase: "Proactive didactic contingency",
        bs: "synergize scalable supply-chains",
      },
      date: "2022-09-22",
      active: false,
      age: 20,
    },
    {
      id: 3,
      name: "Clementine Bauch",
      username: "Samantha",
      email: "Nathan@yesenia.net",
      address: {
        street: "Douglas Extension",
        suite: "Suite 847",
        city: "McKenziehaven",
        zipcode: "59590-4157",
        geo: {
          lat: "-68.6102",
          lng: "-47.0653",
        },
      },
      phone: "1-463-123-4447",
      website: "ramiro.info",
      company: {
        name: "Romaguera-Jacobson",
        catchPhrase: "Face to face bifurcated interface",
        bs: "e-enable strategic applications",
      },
      date: "2022-04-10T10:20:25",
      active: true,
      age: 25,
    },
    {
      id: 4,
      name: "Patricia Lebsack",
      username: "Karianne",
      email: "Julianne.OConner@kory.org",
      address: {
        street: "Hoeger Mall",
        suite: "Apt. 692",
        city: "South Elvis",
        zipcode: "53919-4257",
        geo: {
          lat: "29.4572",
          lng: "-164.2990",
        },
      },
      phone: "493-170-9623 x156",
      website: "kale.biz",
      company: {
        name: "Robel-Corkery",
        catchPhrase: "Multi-tiered zero tolerance productivity",
        bs: "transition cutting-edge web services",
      },
    },
    {
      id: 5,
      name: "Chelsey Dietrich",
      username: "Kamren",
      email: "Lucio_Hettinger@annie.ca",
      address: {
        street: "Skiles Walks",
        suite: "Suite 351",
        city: "Roscoeview",
        zipcode: "33263",
        geo: {
          lat: "-31.8129",
          lng: "62.5342",
        },
      },
      phone: "(254)954-1289",
      website: "demarco.info",
      company: {
        name: "Keebler LLC",
        catchPhrase: "User-centric fault-tolerant solution",
        bs: "revolutionize end-to-end systems",
      },
      age: 56,
    },
    {
      id: 6,
      name: "Mrs. Dennis Schulist",
      username: "Leopoldo_Corkery",
      email: "Karley_Dach@jasper.info",
      address: {
        street: "Norberto Crossing",
        suite: "Apt. 950",
        city: "South Christy",
        zipcode: "23505-1337",
        geo: {
          lat: "-71.4197",
          lng: "71.7478",
        },
      },
      phone: "1-477-935-8478 x6430",
      website: "ola.org",
      company: {
        name: "Considine-Lockman",
        catchPhrase: "Synchronised bottom-line interface",
        bs: "e-enable innovative applications",
      },
    },
    {
      id: 7,
      name: "Kurtis Weissnat",
      username: "Elwyn.Skiles",
      email: "Telly.Hoeger@billy.biz",
      address: {
        street: "Rex Trail",
        suite: "Suite 280",
        city: "Howemouth",
        zipcode: "58804-1099",
        geo: {
          lat: "24.8918",
          lng: "21.8984",
        },
      },
      phone: "210.067.6132",
      website: "elvis.io",
      company: {
        name: "Johns Group",
        catchPhrase: "Configurable multimedia task-force",
        bs: "generate enterprise e-tailers",
      },
      age: 67.35,
    },
    {
      id: 8,
      name: "Nicholas Runolfsdottir V",
      username: "Maxime_Nienow",
      email: "Sherwood@rosamond.me",
      address: {
        street: "Ellsworth Summit",
        suite: "Suite 729",
        city: "Aliyaview",
        zipcode: "45169",
        geo: {
          lat: "-14.3990",
          lng: "-120.7677",
        },
      },
      phone: "586.493.6943 x140",
      website: "jacynthe.com",
      company: {
        name: "Abernathy Group",
        catchPhrase: "Implemented secondary concept",
        bs: "e-enable extensible e-tailers",
      },
    },
    {
      id: 9,
      name: "Glenna Reichert",
      username: "Delphine",
      email: "Chaim_McDermott@dana.io",
      address: {
        street: "Dayna Park",
        suite: "Suite 449",
        city: "Bartholomebury",
        zipcode: "76495-3109",
        geo: {
          lat: "24.6463",
          lng: "-168.8889",
        },
      },
      phone: "(775)976-6794 x41206",
      website: "conrad.com",
      company: {
        name: "Yost and Sons",
        catchPhrase: "Switchable contextually-based project",
        bs: "aggregate real-time technologies",
      },
    },
    {
      id: 10,
      name: "Clementina DuBuque",
      username: "Moriah.Stanton",
      email: "Rey.Padberg@karina.biz",
      address: {
        street: "Kattie Turnpike",
        suite: "Suite 198",
        city: "Lebsackbury",
        zipcode: "31428-2261",
        geo: {
          lat: "-38.2386",
          lng: "57.2232",
        },
      },
      phone: "024-648-3804",
      website: "ambrose.net",
      company: {
        name: "Hoeger LLC",
        catchPhrase: "Centralized empowering task-force",
        bs: "target end-to-end models",
      },
    },
  ]);
</script>
```

## Props

| Props            | Type                    | Default                             | Description                         |
| ---------------- | :---------------------- | ----------------------------------- | ----------------------------------- |
| columns          | array<colDef>           | []                                  | table columns                       |
| rows             | array<any>              | []                                  | table rows                          |
| totalRows        | number                  | 0                                   | total number of rows                |
| skin             | string                  | "table-striped table-hover"         | custom class for skin               |
| loading          | boolean                 | false                               | enable loader                       |
| hasCheckbox      | boolean                 | false                               | enable checkbox                     |
| search           | string                  | ""                                  | enable global search                |
| pageSize         | number                  | 10                                  | number of rows per page             |
| pageSizeOptions  | array<number>           | [10, 20, 30, 50, 100]               | pagesize options                    |
| showPageSize     | boolean                 | true                                | enable pagesize options             |
| rowClass         | array<string>, function | ""                                  | custom row class                    |
| cellClass        | array<string>, function | ""                                  | custom cell class                   |
| sortable         | boolean                 | true                                | enable sorting                      |
| sortColumn       | string                  | "id"                                | name of sort column                 |
| sortDirection    | string                  | "desc"                              | sort direction (asc or desc)        |
| columnFilter     | boolean                 | false                               | enable individual column filter     |
| pagination       | boolean                 | true                                | enable pagination                   |
| showNumbers      | boolean                 | true                                | enable numbers pagination           |
| showNumbersCount | number                  | 5                                   | show numbers of count in pagination |
| showFirstPage    | boolean                 | true                                | enable first page in pagination     |
| showLastPage     | boolean                 | true                                | enable last page in pagination      |
| firstArrow       | string                  | default arrow                       | custom arrow                        |
| lastArrow        | string                  | default arrow                       | custom arrow                        |
| previousArrow    | string                  | default arrow                       | custom arrow                        |
| nextArrow        | string                  | default arrow                       | custom arrow                        |
| paginationInfo   | string                  | "Showing {0} to {1} of {2} entries" | custom pagination info              |
| noDataContent    | string                  | No data available                   | custom no data message              |

## columns options

| Props        | Type             | Default   | Description                                           |
| ------------ | :--------------- | --------- | ----------------------------------------------------- |
| field        | string           | ""        | db column name                                        |
| title        | string           | ""        | display column name                                   |
| value        | string           | ""        | filter value if filter enabled                        |
| condition    | string           | "contain" | default condition for column filter if filter enabled |
| type         | string           | ""        | column type (string, date, number, bool)              |
| width        | string           | ""        | custom width of column                                |
| minWidth     | string           | ""        | custom minimum width of column                        |
| maxWidth     | string           | ""        | custom maximum width of column                        |
| hide         | boolean          | false     | show/hide column                                      |
| filter       | boolean          | true      | enable column filter                                  |
| search       | boolean          | true      | enabled global search                                 |
| sort         | boolean          | true      | enable sorting                                        |
| slotMode     | boolean          | false     | enable slot for cell rendering                        |
| cellRenderer | function, string | true      | custom cell rendering                                 |

## Events

| Name           | Description                             |
| -------------- | --------------------------------------- |
| sortChange     | will trigger when sorting changed       |
| searchChange   | will trigger when search changed        |
| pageChange     | will trigger when page changed          |
| pageSizeChange | will trigger when pagesize changed      |
| filterChange   | will trigger when column filter changed |

## License

MIT
